@@ -1,16 +1,16 @@
 package Weed::Tie::ArrayLength;
 use Weed::Perl;
 
-our $VERSION = '0.0079';
+our $VERSION = '0.008';
 
 use Tie::Scalar;
 use base 'Tie::StdScalar';
 
 sub TIESCALAR { bless \$_[1], $_[0] }
 
-sub FETCH { ${ $_[0] }->getLength }
+sub FETCH { @${ $_[0] } }
 
-sub STORE { ${ $_[0] }->setLength($_[1]) }
+sub STORE { $#${ $_[0] } = $_[1] - 1 }
 
 1;
 __END__
