@@ -1,14 +1,14 @@
 package Weed::Tie::Field;
 use Weed::Perl;
 
-our $VERSION = '0.0079';
+our $VERSION = '0.008';
 
 use Tie::Scalar;
 use base 'Tie::StdScalar';
 
 sub TIESCALAR { bless \$_[1], $_[0] }
 
-sub FETCH { ${ $_[0] }->getClone->getValue }
+sub FETCH { ${ $_[0] }->getClone }
 
 sub STORE { ${ $_[0] }->setValue( $_[1] ) }
 
